@@ -518,7 +518,12 @@ LoadPars <- function(itemtype, itemloc, lambdas, zetas, guess, upper, fulldata,
                                                      'lnorm'=exp(p1[w]),
                                                      'beta'=(p1[w]-1)/(p1[w] + p2[w] - 2),
                                                      'expbeta'=expbeta_sv(p1[w], p2[w]))
-
+                        if(type[w] == 'lnorm')
+                            pars[[i]]@lbound[whc[w]] <- 0
+                        if(type[w] == 'beta'){
+                            pars[[i]]@lbound[whc[w]] <- 0
+                            pars[[i]]@ubound[whc[w]] <- 1
+                        }
                     }
                     pars[[i]]@prior_1[tmp] <- p1
                     pars[[i]]@prior_2[tmp] <- p2
